use crate::spotify_types::*;
use sqlx::{
    MySqlPool,
};

#[allow(non_snake_case)] // Fixes warning for macro
pub async fn even_allocation(pool: &MySqlPool) -> Result<Vec<Uri>, sqlx::Error> {
    let users: Vec<u32> = sqlx::query!(
        "
        SELECT UserId From Users
        "
    )
    .fetch_all(pool)
    .await?
    .iter()
    .map(|row| row.UserId)
    .collect();

    // Reset the SQL playlist representation
    sqlx::query!("UPDATE Tracks SET InPlaylist = 0")
        .execute(pool)
        .await?;

    let num: u32 = (100 / users.len()) as u32;
    for user in users {
        sqlx::query!(
            "
            UPDATE Tracks SET InPlaylist = 1
            WHERE TrackID In
            (
            SELECT TrackId FROM Tracks
            WHERE UserId = ?
            )
            ORDER BY RAND()
            LIMIT ?
            ",
            user,
            num
        )
        .execute(pool)
        .await?;
    }
    let uris = sqlx::query!(
        "
        SELECT Uri FROM Tracks
        WHERE InPlaylist = 1
        "
    )
    .fetch_all(pool)
    .await?
    .iter()
    .map(|row| Uri(row.Uri.clone()))
    .collect();

    Ok(uris)
}
